@@ -44,6 +44,8 @@ class ProtocolCode(object):
     GET_ANGLE = 0x2C
     GET_COORD = 0x2D
     SEND_ANGLES_AUTO = 0x2E
+    GET_SOLUTION_ANGLES = 0x2E
+    SET_SOLUTION_ANGLES = 0x2F
 
     # JOG MODE AND OPERATION
     JOG_ANGLE = 0x30
@@ -92,6 +94,8 @@ class ProtocolCode(object):
     SET_COLOR = 0x6A
     SET_ELETRIC_GRIPPER = 0x6B
     INIT_ELETRIC_GRIPPER = 0x6C
+    SET_GRIPPER_MODE = 0x6D
+    GET_GRIPPER_MODE = 0x6E
 
     GET_ACCEI_DATA = 0x73
 
@@ -144,6 +148,7 @@ class ProtocolCode(object):
     GET_SERVO_VOLTAGES = 0xE3
     GET_SERVO_STATUS = 0xE4
     GET_SERVO_TEMPS = 0xE5
+    GET_SERVO_LASTPDI = 0xE6
 
     GET_BASE_COORDS = 0xF0
     BASE_TO_SINGLE_COORDS = 0xF1
@@ -181,7 +186,7 @@ class ProtocolCode(object):
     SET_ANGLES = "M11"
     GET_CURRENT_ANGLE_INFO = "M12"
     SET_JOG_ANGLE = "M13"
-    JOG_COORD = "M14"
+    JOG_COORD_ = "M14"
     SET_JOG_STOP = "M15"
     RELEASE_SERVOS = "M17"
     LOCK_SERVOS = "M18"
@@ -284,7 +289,7 @@ class DataProcessor(object):
 
         # process valid data
         res = []
-        if data_len in [6, 8, 12, 24, 60]:
+        if data_len in [6, 8, 12, 14, 24, 60]:
             for header_i in range(0, len(valid_data), 2):
                 one = valid_data[header_i : header_i + 2]
                 res.append(self._decode_int16(one))
@@ -302,6 +307,9 @@ class DataProcessor(object):
             res.append(self._decode_int16(valid_data))
         elif data_len == 3:
             res.append(self._decode_int16(valid_data[1:]))
+        elif data_len == 4:
+            for i in range(1,4):
+                res.append(valid_data[i])
         elif data_len == 7:
             error_list = [i for i in valid_data]
             for i in error_list:
@@ -405,4 +413,5 @@ def read(self, genre):
                     pre = k
     else:
         datas = None
+    self.log.debug("_read: {}".format(datas))
     return datas
