@@ -84,6 +84,8 @@ class MyCobot(MyCobotCommandGenerator):
 
         if has_reply:
             data = self._read(genre)
+            if genre == ProtocolCode.SET_SSID_PWD:
+                return None
             res = self._process_received(data, genre)
             if genre in [
                 ProtocolCode.ROBOT_VERSION,
@@ -107,7 +109,9 @@ class MyCobot(MyCobotCommandGenerator):
                 ProtocolCode.GET_MOVEMENT_TYPE,
                 ProtocolCode.GET_REFERENCE_FRAME,
                 ProtocolCode.GET_JOINT_MIN_ANGLE,
-                ProtocolCode.GET_JOINT_MAX_ANGLE
+                ProtocolCode.GET_JOINT_MAX_ANGLE,
+                ProtocolCode.GET_FRESH_MODE,
+                ProtocolCode.GET_GRIPPER_MODE
             ]:
                 return self._process_single(res)
             elif genre in [ProtocolCode.GET_ANGLES]:
